@@ -45,13 +45,19 @@ def get_neg_bagging_fraction_params(y_train=None,params=None,log=0):
     return params
 
 
-def get_scale_pos_weight_params(y_train,params):
+def get_scale_pos_weight_params(y_train=None,params=None,log=0):
     
     N_p = y_train[y_train==1].count()
     N_n = y_train[y_train==0].count()
     
     T_minimo = get_Total_min_to_train(N_p)
     
+    if  log is not None and log>0 :
+    
+        print("T_minimo : ",T_minimo)
+        print("N_p : ",N_p)
+        print("N_n : ",N_n)
+    
     alpha = (T_minimo-N_p)/N_n
     if params is None:
         params = get_default_params()
@@ -155,11 +161,12 @@ def modelar(X_train=None,y_train=None,X_test=None,y_test=None,params=None,metric
     start = time.time()
     model = None
     
+    print("strategy: ",strategy)
     if (strategy=="neg_bagging_fraction__lgb_model"):
         params = get_neg_bagging_fraction_params(y_train,params)
         
     if (strategy=="scale_pos_weight__lgb_model"):
-        params = get_neg_bagging_fraction_params(y_train,params)
+        params = get_scale_pos_weight_params(y_train,params)
 
     
     if api=="train_api":
